@@ -23,6 +23,7 @@
 
 #include "e-book-backend-couchdb.h"
 #include <libedata-book/e-data-book.h>
+#include <libedata-book/e-data-book-view.h>
 
 G_DEFINE_TYPE (EBookBackendCouchDB, e_book_backend_couchdb, E_TYPE_BOOK_BACKEND);
 
@@ -322,8 +323,6 @@ e_book_backend_couchdb_load_source (EBookBackend *backend,
 					     couchdb_backend->dbname,
 					     &error);
 	if (!db_info) {
-		couchdb_free_database_info (db_info);
-
 		if (only_if_exists)
 			return GNOME_Evolution_Addressbook_NoSuchBook;
 		
@@ -333,7 +332,8 @@ e_book_backend_couchdb_load_source (EBookBackend *backend,
 					      couchdb_backend->dbname,
 					      &error))
 			return GNOME_Evolution_Addressbook_PermissionDenied;
-	}
+	} else
+		couchdb_database_info_unref (db_info);
 
 	e_book_backend_set_is_loaded (backend, TRUE);
 	e_book_backend_set_is_writable (backend, TRUE);
